// G4 headers
#include "G4ParticleTable.hh"

// Qt headers
#include <QtGui>

// gemc headers
#include "detector.h"
#include "run_control.h"
#include "string_utilities.h"

// C++ headers
#include <ctime>

run_control::run_control(QWidget *parent, goptions *Opts) : QWidget(parent)
{
	gemcOpt   = Opts;
	UImanager  = G4UImanager::GetUIpointer();

	QTabWidget* BeamType = new QTabWidget;
	pbeamtab  = new particleTab(this, gemcOpt, "Primary");
	lbeamtab  = new particleTab(this, gemcOpt, "Lumi1");
	lbeamtab2 = new particleTab(this, gemcOpt, "Lumi2");
	
	BeamType->addTab(pbeamtab,  tr("Generator"));
	BeamType->addTab(lbeamtab,  tr("Beam 1"));
	BeamType->addTab(lbeamtab2, tr("Beam 2"));
	
	
	BeamType->setStyleSheet(QString("QTabBar::tab:selected { background-color:  rgb(124,  164, 210); } "));

	QPushButton *BeamOn = new QPushButton(tr("Beam On"));
	connect ( BeamOn , SIGNAL( pressed() ), this, SLOT( beamOn() ) );
  
	QPushButton *BeamE2S = new QPushButton(tr("Beam Every 2 seconds"));
	connect ( BeamE2S , SIGNAL( pressed() ), this, SLOT( beam_every2sec() ) );
  

	QGroupBox *neventsGroup = new QGroupBox(tr("Number of Events"));
	
	QLabel *set_nevents = new QLabel(tr("Set N:"));
	n_units = new QComboBox;
	n_units->addItem(tr("1")); 
	n_units->addItem(tr("10"));
	n_units->addItem(tr("50")); 
	n_units->setMaximumWidth(55);
	connect ( n_units , SIGNAL( currentIndexChanged(int) ), this, SLOT( set_beam_values() ) );

	
	QLabel *times = new QLabel(tr("X"));
	n_mult = new QComboBox;
	n_mult->addItem(tr("1"));
	n_mult->addItem(tr("10"));
	n_mult->addItem(tr("100"));
	n_mult->addItem(tr("1000"));
	n_mult->addItem(tr("10000"));
	n_mult->addItem(tr("100000"));
	n_mult->addItem(tr("1000000"));
	n_mult->setMaximumWidth(95);
	connect ( n_mult , SIGNAL( currentIndexChanged(int) ), this, SLOT( set_beam_values() ) );

	nevents = new QLabel(tr(""));

	QHBoxLayout *bottomLayout = new QHBoxLayout;
	bottomLayout->addWidget(set_nevents);
	bottomLayout->addWidget(n_units);
	bottomLayout->addWidget(times);
	bottomLayout->addWidget(n_mult);
	bottomLayout->addSpacing(30);
	bottomLayout->addWidget(nevents);
	bottomLayout->addSpacing(30);
	bottomLayout->addWidget(BeamE2S);
	bottomLayout->addStretch(2);
	neventsGroup->setLayout(bottomLayout);
	
	QVBoxLayout *mainLayout = new QVBoxLayout;
	mainLayout->addWidget(BeamType);
	mainLayout->addWidget(neventsGroup);
	mainLayout->addSpacing(5);
	mainLayout->addWidget(BeamOn);
	setLayout(mainLayout);

 	set_beam_values();
	set_vertex_values();
	gemcOpt->optMap["N"].arg = 0;
	
}

run_control::~run_control()
{
	string hd_msg = gemcOpt->optMap["LOG_MSG"].args ;
	double VERB   = gemcOpt->optMap["GEO_VERBOSITY"].arg ;
	
	if(VERB>2)
		cout << hd_msg << " Run Control Widget Deleted." << endl;
}



void run_control::beamOn()
{
	double N_units = atoi(qs_tostring(n_units->currentText()).c_str());
	double N_mult  = atoi(qs_tostring(n_mult->currentText()).c_str());
	double NEVENTS = N_units*N_mult;
	gemcOpt->optMap["N"].arg = NEVENTS;
	
	char command[100];
	sprintf(command, "/run/beamOn %d", (int) NEVENTS);
	UImanager->ApplyCommand(command);	
}

void run_control::beam_every2sec()
{
	// will execute beam on every 2 seconds for 600 times (10 minutes)
	for(int s=0; s<600; s++)
  {
    char command[100];

    sprintf(command, "/vis/viewer/refresh");
    UImanager->ApplyCommand(command);	
		
    clock_t endwait = clock () + 2 * CLOCKS_PER_SEC ;
    while (clock() < endwait) {}

    sprintf(command, "/run/beamOn 1");
    UImanager->ApplyCommand(command);
	}
}




#include "MPrimaryGeneratorAction.h"

void run_control::set_beam_values()
{
	pbeamtab->momentumControls->set_momentum_ro();
	pbeamtab->momentumControls->set_rmomentum_ro();
	pbeamtab->momentumControls->set_theta_ro();
	pbeamtab->momentumControls->set_phi_ro();
	
	lbeamtab->momentumControls->set_momentum_ro();
	lbeamtab->momentumControls->set_theta_ro();
	lbeamtab->momentumControls->set_phi_ro();
	
	lbeamtab2->momentumControls->set_momentum_ro();
	lbeamtab2->momentumControls->set_theta_ro();
	lbeamtab2->momentumControls->set_phi_ro();
	
	
	double N_units = atoi(qs_tostring(n_units->currentText()).c_str());
	double N_mult  = atoi(qs_tostring(n_mult->currentText()).c_str());
	double NEVENTS = N_units*N_mult;
	QString nev = "Number of Events: " ;
	nev.append(stringify(NEVENTS).c_str());
	nevents->setText(nev);
	
	
	change_beam_pars();
}

void run_control::set_vertex_values()
{
	pbeamtab->vertexControls->set_vxyz_ro();
	pbeamtab->vertexControls->set_vdr_ro();
	pbeamtab->vertexControls->set_vdz_ro();
	
	lbeamtab->vertexControls->set_vxyz_ro();
	lbeamtab->vertexControls->set_vdr_ro();
	lbeamtab->vertexControls->set_vdz_ro();
	
	lbeamtab2->vertexControls->set_vxyz_ro();
	lbeamtab2->vertexControls->set_vdr_ro();
	lbeamtab2->vertexControls->set_vdz_ro();
	
	change_beam_pars();
}


void run_control::change_beam_pars()
{

	// Momentum
	gemcOpt->optMap["BEAM_P"].args         = pbeamtab->get_momentum();
	gemcOpt->optMap["SPREAD_P"].args       = pbeamtab->get_rmomentum();
	
	gemcOpt->optMap["LUMI_P"].args         = lbeamtab->get_momentum();
	gemcOpt->optMap["LUMI_SPREAD_P"].args  = lbeamtab->get_rmomentum();
	
	gemcOpt->optMap["LUMI2_P"].args        = lbeamtab2->get_momentum();
	gemcOpt->optMap["LUMI2_SPREAD_P"].args = lbeamtab2->get_rmomentum();
	

	// Vertex
	gemcOpt->optMap["BEAM_V"].args         = pbeamtab->get_vertex();
	gemcOpt->optMap["SPREAD_V"].args       = pbeamtab->get_rvertex();
	
	gemcOpt->optMap["LUMI_V"].args         = lbeamtab->get_vertex();
	gemcOpt->optMap["LUMI_SPREAD_V"].args  = lbeamtab->get_rvertex();
	
	gemcOpt->optMap["LUMI2_V"].args        = lbeamtab2->get_vertex();
	gemcOpt->optMap["LUMI2_SPREAD_V"].args = lbeamtab2->get_rvertex();
	

	// Luminosity Event
	gemcOpt->optMap["LUMI_EVENT"].args     = lbeamtab->get_lumi_event(0);
	gemcOpt->optMap["LUMI2_EVENT"].args    = lbeamtab2->get_lumi_event(lbeamtab->get_time_window());
	
}















